camelot.camelot.model.memento.BeforeDelete

Package camelot :: Package camelot :: Package model :: Module memento :: Class BeforeDelete |
[hide private]
[frames] | no frames]

# Class BeforeDelete

source code

The state of the object before it is deleted

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
description(self) | source code

Class Variables | [hide private]
| previous_attributes = `Field(PickleType())`
Inherited from `Memento`: `creation_date`, `model`, `person`, `primary_key`

Method Details | [hide private]

### description(self) | source code
Decorators: `@property` Overrides: description